==> ejc-lz-impl-3.0.0-20220302.022755-3-sources.jar: com/ejianc/business/base/vo/ShippersVehicleVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 运输车辆信息
 * 
 * @author generator
 * 
 */
public class ShippersVehicleVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private String name; // 运输商名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String operatorId; // 经办人id
    private String operatorName; // 经办人名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Long shipperMId; // 运输商管理档案主键
    private String plateNumber; // 车牌号码
    private Integer greenPlate; // 绿牌（1:是,0:否）
    private BigDecimal tonnage; // 吨位
    private String vehicleExplain; // 车辆说明
    private String vehiclePic; // 车辆照片
    private String driver; // 司机姓名
    private String driverPhone; // 司机联系方式
    private String driverWx; // 司机微信ID
    private Integer receive; // 收货（1:是,0:否）
    private Integer delivery; // 发货（1:是,0:否）
    private Integer pour; // 倒料（1:是,0:否）
    private String cdefine1; // 
    private String cdefine2; // 
    private String cdefine3; // 
    private String cdefine4; // 
    private String cdefine5; // 
    private String cdefine6; // 
    private String cdefine7; // 
    private String cdefine8; // 
    private String cdefine9; // 
    private String cdefine10; // 
    private Integer cdefine11; // 
    private Integer cdefine12; // 
    private BigDecimal cdefine13; // 
    private BigDecimal cdefine14; // 
    private Date cdefine15; // 
    private Date cdefine16; // 
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public String getOperatorId() {
        return operatorId;
    }
    @ReferDeserialTransfer
    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    public Long getShipperMId() {
        return shipperMId;
    }

    public void setShipperMId(Long shipperMId) {
        this.shipperMId = shipperMId;
    }
    public String getPlateNumber() {
        return plateNumber;
    }

    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    public Integer getGreenPlate() {
        return greenPlate;
    }

    public void setGreenPlate(Integer greenPlate) {
        this.greenPlate = greenPlate;
    }
    public BigDecimal getTonnage() {
        return tonnage;
    }

    public void setTonnage(BigDecimal tonnage) {
        this.tonnage = tonnage;
    }
    public String getVehicleExplain() {
        return vehicleExplain;
    }

    public void setVehicleExplain(String vehicleExplain) {
        this.vehicleExplain = vehicleExplain;
    }
    public String getVehiclePic() {
        return vehiclePic;
    }

    public void setVehiclePic(String vehiclePic) {
        this.vehiclePic = vehiclePic;
    }
    public String getDriver() {
        return driver;
    }

    public void setDriver(String driver) {
        this.driver = driver;
    }
    public String getDriverPhone() {
        return driverPhone;
    }

    public void setDriverPhone(String driverPhone) {
        this.driverPhone = driverPhone;
    }
    public String getDriverWx() {
        return driverWx;
    }

    public void setDriverWx(String driverWx) {
        this.driverWx = driverWx;
    }
    public Integer getReceive() {
        return receive;
    }

    public void setReceive(Integer receive) {
        this.receive = receive;
    }
    public Integer getDelivery() {
        return delivery;
    }

    public void setDelivery(Integer delivery) {
        this.delivery = delivery;
    }
    public Integer getPour() {
        return pour;
    }

    public void setPour(Integer pour) {
        this.pour = pour;
    }
    public String getCdefine1() {
        return cdefine1;
    }

    public void setCdefine1(String cdefine1) {
        this.cdefine1 = cdefine1;
    }
    public String getCdefine2() {
        return cdefine2;
    }

    public void setCdefine2(String cdefine2) {
        this.cdefine2 = cdefine2;
    }
    public String getCdefine3() {
        return cdefine3;
    }

    public void setCdefine3(String cdefine3) {
        this.cdefine3 = cdefine3;
    }
    public String getCdefine4() {
        return cdefine4;
    }

    public void setCdefine4(String cdefine4) {
        this.cdefine4 = cdefine4;
    }
    public String getCdefine5() {
        return cdefine5;
    }

    public void setCdefine5(String cdefine5) {
        this.cdefine5 = cdefine5;
    }
    public String getCdefine6() {
        return cdefine6;
    }

    public void setCdefine6(String cdefine6) {
        this.cdefine6 = cdefine6;
    }
    public String getCdefine7() {
        return cdefine7;
    }

    public void setCdefine7(String cdefine7) {
        this.cdefine7 = cdefine7;
    }
    public String getCdefine8() {
        return cdefine8;
    }

    public void setCdefine8(String cdefine8) {
        this.cdefine8 = cdefine8;
    }
    public String getCdefine9() {
        return cdefine9;
    }

    public void setCdefine9(String cdefine9) {
        this.cdefine9 = cdefine9;
    }
    public String getCdefine10() {
        return cdefine10;
    }

    public void setCdefine10(String cdefine10) {
        this.cdefine10 = cdefine10;
    }
    public Integer getCdefine11() {
        return cdefine11;
    }

    public void setCdefine11(Integer cdefine11) {
        this.cdefine11 = cdefine11;
    }
    public Integer getCdefine12() {
        return cdefine12;
    }

    public void setCdefine12(Integer cdefine12) {
        this.cdefine12 = cdefine12;
    }
    public BigDecimal getCdefine13() {
        return cdefine13;
    }

    public void setCdefine13(BigDecimal cdefine13) {
        this.cdefine13 = cdefine13;
    }
    public BigDecimal getCdefine14() {
        return cdefine14;
    }

    public void setCdefine14(BigDecimal cdefine14) {
        this.cdefine14 = cdefine14;
    }
    public Date getCdefine15() {
        return cdefine15;
    }

    public void setCdefine15(Date cdefine15) {
        this.cdefine15 = cdefine15;
    }
    public Date getCdefine16() {
        return cdefine16;
    }

    public void setCdefine16(Date cdefine16) {
        this.cdefine16 = cdefine16;
    }
    
}

==> ejc-lz-impl-3.0.0-20220309.065506-10-sources.jar: com/ejianc/business/base/vo/ShippersVehicleVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 运输车辆信息
 * 
 * @author generator
 * 
 */
public class ShippersVehicleVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private String name; // 运输商名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String operatorId; // 经办人id
    private String operatorName; // 经办人名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Long shipperMId; // 运输商管理档案主键
    private String plateNumber; // 车牌号码
    private Integer greenPlate; // 绿牌（1:是,0:否）
    private BigDecimal tonnage; // 吨位
    private String vehicleExplain; // 车辆说明
    private String vehiclePic; // 车辆照片
    private String driver; // 司机姓名
    private String driverPhone; // 司机联系方式
    private String driverWx; // 司机微信ID
    private Integer receive; // 收货（1:是,0:否）
    private Integer delivery; // 发货（1:是,0:否）
    private Integer pour; // 倒料（1:是,0:否）
    private String cdefine1; // 
    private String cdefine2; // 
    private String cdefine3; // 
    private String cdefine4; // 
    private String cdefine5; // 
    private String cdefine6; // 
    private String cdefine7; // 
    private String cdefine8; // 
    private String cdefine9; // 
    private String cdefine10; // 
    private Integer cdefine11; // 
    private Integer cdefine12; // 
    private BigDecimal cdefine13; // 
    private BigDecimal cdefine14; // 
    private Date cdefine15; // 
    private Date cdefine16; // 
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    @ReferSerialTransfer(referCode="SuppliermanageRef")
    public Long getShipperMId() {
        return shipperMId;
    }

    @ReferDeserialTransfer
    public void setShipperMId(Long shipperMId) {
        this.shipperMId = shipperMId;
    }
    public String getPlateNumber() {
        return plateNumber;
    }

    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    public Integer getGreenPlate() {
        return greenPlate;
    }

    public void setGreenPlate(Integer greenPlate) {
        this.greenPlate = greenPlate;
    }
    public BigDecimal getTonnage() {
        return tonnage;
    }

    public void setTonnage(BigDecimal tonnage) {
        this.tonnage = tonnage;
    }
    public String getVehicleExplain() {
        return vehicleExplain;
    }

    public void setVehicleExplain(String vehicleExplain) {
        this.vehicleExplain = vehicleExplain;
    }
    public String getVehiclePic() {
        return vehiclePic;
    }

    public void setVehiclePic(String vehiclePic) {
        this.vehiclePic = vehiclePic;
    }
    public String getDriver() {
        return driver;
    }

    public void setDriver(String driver) {
        this.driver = driver;
    }
    public String getDriverPhone() {
        return driverPhone;
    }

    public void setDriverPhone(String driverPhone) {
        this.driverPhone = driverPhone;
    }
    public String getDriverWx() {
        return driverWx;
    }

    public void setDriverWx(String driverWx) {
        this.driverWx = driverWx;
    }
    public Integer getReceive() {
        return receive;
    }

    public void setReceive(Integer receive) {
        this.receive = receive;
    }
    public Integer getDelivery() {
        return delivery;
    }

    public void setDelivery(Integer delivery) {
        this.delivery = delivery;
    }
    public Integer getPour() {
        return pour;
    }

    public void setPour(Integer pour) {
        this.pour = pour;
    }
    public String getCdefine1() {
        return cdefine1;
    }

    public void setCdefine1(String cdefine1) {
        this.cdefine1 = cdefine1;
    }
    public String getCdefine2() {
        return cdefine2;
    }

    public void setCdefine2(String cdefine2) {
        this.cdefine2 = cdefine2;
    }
    public String getCdefine3() {
        return cdefine3;
    }

    public void setCdefine3(String cdefine3) {
        this.cdefine3 = cdefine3;
    }
    public String getCdefine4() {
        return cdefine4;
    }

    public void setCdefine4(String cdefine4) {
        this.cdefine4 = cdefine4;
    }
    public String getCdefine5() {
        return cdefine5;
    }

    public void setCdefine5(String cdefine5) {
        this.cdefine5 = cdefine5;
    }
    public String getCdefine6() {
        return cdefine6;
    }

    public void setCdefine6(String cdefine6) {
        this.cdefine6 = cdefine6;
    }
    public String getCdefine7() {
        return cdefine7;
    }

    public void setCdefine7(String cdefine7) {
        this.cdefine7 = cdefine7;
    }
    public String getCdefine8() {
        return cdefine8;
    }

    public void setCdefine8(String cdefine8) {
        this.cdefine8 = cdefine8;
    }
    public String getCdefine9() {
        return cdefine9;
    }

    public void setCdefine9(String cdefine9) {
        this.cdefine9 = cdefine9;
    }
    public String getCdefine10() {
        return cdefine10;
    }

    public void setCdefine10(String cdefine10) {
        this.cdefine10 = cdefine10;
    }
    public Integer getCdefine11() {
        return cdefine11;
    }

    public void setCdefine11(Integer cdefine11) {
        this.cdefine11 = cdefine11;
    }
    public Integer getCdefine12() {
        return cdefine12;
    }

    public void setCdefine12(Integer cdefine12) {
        this.cdefine12 = cdefine12;
    }
    public BigDecimal getCdefine13() {
        return cdefine13;
    }

    public void setCdefine13(BigDecimal cdefine13) {
        this.cdefine13 = cdefine13;
    }
    public BigDecimal getCdefine14() {
        return cdefine14;
    }

    public void setCdefine14(BigDecimal cdefine14) {
        this.cdefine14 = cdefine14;
    }
    public Date getCdefine15() {
        return cdefine15;
    }

    public void setCdefine15(Date cdefine15) {
        this.cdefine15 = cdefine15;
    }
    public Date getCdefine16() {
        return cdefine16;
    }

    public void setCdefine16(Date cdefine16) {
        this.cdefine16 = cdefine16;
    }
    
}
